@import url(http://fonts.googleapis.com/css?family=Press+Start+2P);

img.badge {
    width: 64px;
    height: 64px;
}

body {
    font-family: 'Press Start 2P', cursive;
    background-color: #1E1E1E;
}

.strong {
    font-weight: bold;
    text-decoration: underline;
}

.header {
    color: #C1C1C1;
}

.subheader a {
    color: #D01A55;
}

.content a {
    color: #D01A55;
}

.subheader {
    padding: 20px;
    color: #C1C1C1;
    width: 700px;
    margin-right: auto;
    margin-left: auto;
    text-align: right;
    font-size: 90%;
}

.content {
    background-color: #C1C1C1;
    color: #1E1E1E !important;
    width: 700px;
    margin-right: auto;
    margin-left: auto;

    -moz-border-radius: 10px;
    border-radius: 10px;
    border: 1px solid black;
}

table {
    margin-right:auto;
    margin-left:auto;
}
td {
    padding: 5px;
}
